package org.eclipse.scripting.examples;

/*
 * (c) Copyright IBM Corp. 2000, 2001.
 * All Rights Reserved.
 */

/**
 * This class is an example of a Scripting program
 */
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.*;
import org.eclipse.ui.*;
import org.eclipse.core.resources.*;
import org.eclipse.core.runtime.*;
import org.eclipse.swt.widgets.*;

import org.eclipse.scripting.*;

import java.net.*;

public class ExcaliburScriptRenderer implements IWorkbenchWindowActionDelegate, IExecutableExtension {
	Renderer             renderer         = null;
	IStructuredSelection elementSelection = null;
	String               installLocation  = null;
	IContainer           container        = null;
/**
 * This constructor does nothing other than construct the class
 */
public ExcaliburScriptRenderer() {
	super();
}
/**
 * This method is called when button1 is clicked.
 */
public void button1onclick() {

	IToolkit toolkit = this.renderer.getToolkit();

	toolkit.print("Hi!  This is button1onclick!");

	try {
		this.container = toolkit.promptForWorkspaceContainer(null, "Excalibur");
		
		Text textField = (Text) this.renderer.getWidget("textWorkspaceContainer");
		
		if (this.container != null)
			textField.setText(container.getFullPath().toString());
		else
			textField.setText("");
	}

	catch (Exception ex) {
		toolkit.print("An exception has occurred in button1click");
		toolkit.print(ex);
	}
}
/**
 * This method is called when button2 is clicked.
 */
public void button2onclick() {
	
	IToolkit toolkit = this.renderer.getToolkit();
	
	toolkit.print("Hi!  This is button2onclick!");
	
	try {
		IFile[] files = toolkit.promptForWorkspaceFiles(container, "File Selection");
		
		if (files != null) {
			
			List list = (List) this.renderer.getWidget("listWorkspaceFiles");
			list.removeAll();
			
			for (int i = 0; i < files.length; i++) {
				list.add(files[i].getFullPath().toString());
			}
		}
	}
	
	catch (Exception ex) {
		toolkit.print("An exception has occurred in button2click");
		toolkit.print(ex);
	}
}
/**
 * This method is called when button3 is clicked.
 */
public void button3onclick() {
	
	IToolkit toolkit = this.renderer.getToolkit();
	
	toolkit.print("Hi!  This is button3onclick!");
	
	try {
		IPath path = toolkit.promptForSystemFolder();
		
		if (path != null) {
			Text textField = (Text) this.renderer.getWidget("textSystemFolder");
			textField.setText(path.toOSString());
		}
	}
	
	catch (Exception ex) {
		toolkit.print("An exception has occurred in button3click");
		toolkit.print(ex);
	}
}
/**
 * This method is called when button4 is clicked.
 */
public void button4onclick() {
	IToolkit toolkit = this.renderer.getToolkit();
	
	toolkit.print("Hi!  This is button4onclick!");
	
	try {
		IPath path = toolkit.promptForSystemFile(false);
		
		if (path != null) {
			Text textField = (Text) this.renderer.getWidget("textSystemFile");
			textField.setText(path.toOSString());
		}
	}
	
	catch (Exception ex) {
		toolkit.print("An exception has occurred in button4click");
		toolkit.print(ex);
	}
}
/**
 * This method is called when button5 is clicked.
 */
public void button5onclick() {
	
	IToolkit toolkit = this.renderer.getToolkit();
	
	toolkit.print("Hi!  This is button5onclick!");
	
	try {
		String strMessageType = null;
		String strMessage = null;
		
		Button radio = (Button) this.renderer.getWidget("radioInformation");
		
		if (radio.getSelection() == true) {
			strMessageType = "information";
			strMessage = "Information Message";
		}
		
		radio = (Button) this.renderer.getWidget("radioWarning");
		
		if (radio.getSelection() == true) {
			strMessageType = "warning";
			strMessage = "Warning Message";
		}
		
		radio = (Button) this.renderer.getWidget("radioError");
		
		if (radio.getSelection() == true) {
			strMessageType = "error";
			strMessage = "Error Message";
		}
		
		toolkit.promptForOk("Prompt for OK Title", strMessage, strMessageType);
	}
	
	catch (Exception ex) {
		toolkit.print("An exception has occurred in button5click");
		toolkit.print(ex);
	}
}
/**
 * This method is called when button6 is clicked.
 */
public void button6onclick() {
	
	IToolkit toolkit = this.renderer.getToolkit();
	
	toolkit.print("Hi!  This is button6onclick!");
	
	try {
		boolean bOk = toolkit.promptForOkCancel("Prompt for OK/Cancel Title", "Prompt for OK/Cancel Message");
		
		if (bOk == true) {
			toolkit.print("  OK button was pressed");
		}
		
		else {
			toolkit.print("  Cancel button was pressed");
		}
	}
	
	catch (Exception ex) {
		toolkit.print("An exception has occurred in button6click");
		toolkit.print(ex);
	}
}
/**
 * This method is called when the wizard or prefereneces dialog is loaded.
 */
public void dialog1onload() {
	renderer.getToolkit().print("Hi!  This is dialog1onload!");
}
/**
 * This method is called when either the wizard or preferences dialog is closed.
 */
public void dialog1onunload() {
	
	renderer.getToolkit().print("Hi!  This is dialog1onunload!");

	// Get the widget given the id
	//----------------------------
	Object objWidget = this.renderer.getWidget("dialog1");
	
	boolean bCancel = ((ICancel) objWidget).isCancel();
	
	if (bCancel == true) {
		this.renderer.getToolkit().print("  Cancel button was pressed");
	}
	
	else {
		this.renderer.getToolkit().print("  Finish button was pressed.");

		// Save the data
		//--------------
/*		
		IDataModel dataModel = this.renderer.getToolkit().getUIDataModel();
		
		if (dataModel != null) {
			
			try {
				dataModel.save();
			}
			
			catch (Exception ex) {
				this.renderer.getToolkit().print(ex.toString());
			}
		}
*/
	}
}
/**
 * This implementation does nothing.
 */
public void dispose() {}
/**
 * This implementation does nothing.
 *
 * @param window the window that provides the context for this delegate
 */
public void init(org.eclipse.ui.IWorkbenchWindow window) {}
/**
 * This method is called when a selection on a listbox has changed.
 */
public void list1onchange() {
	renderer.getToolkit().print("Hi!  This is list1onchange!");
}
/**
 * This method is called when the first page is opened.
 */
public void page1onreset() {
	this.renderer.getToolkit().print("Hi!  This is page1onreset!");
}
/**
 * This method is called when leaving a wizard page, or when
 * either the default, or apply button is pressed on a preferences
 * page.
 */
public void page1onsubmit() {
	
	IToolkitUI toolkit = this.renderer.getToolkit();
	
	toolkit.print("Hi!  This is page1onsubmit!");

	// Get the widget given the id
	//----------------------------
	Object objWidget = this.renderer.getWidget("page1");

	// IDefault is applicable to preference pages
	// but not wizard pages
	//-------------------------------------------
	if (objWidget instanceof IDefault) {
		
		boolean bDefault = ((IDefault) objWidget).isDefault();
		
		if (bDefault == true) {
			toolkit.print("  Default button was pressed");
		}
		
		else {
			toolkit.print("  Apply button was pressed");
		}
	}
}
/**
 * This method is called when the second page is opened.  User interface elements
 * are associated with a datamodel's data source.  Some user interface elements are
 * linked to other user interface element sources.
 */
public void page2onreset() {
	
	IToolkitUI toolkit = this.renderer.getToolkit();
	
	toolkit.print("Hi!  This is page2onreset!");
	
	toolkit.setDataSource("company_address_street", "company.address.street");
	toolkit.setDataSource("company_address_city", "company.address.city");
	toolkit.setDataSource("company_address_country", "company.address.country");
	toolkit.setDataSource("list1_company_department", "company.department.number");
	toolkit.setDataSource("list2_company_department_employee_linkedto_list1", "company.department.employee.name");
	toolkit.setDataSource("textfield_company_department_employee", "company.department.employee.name");
	toolkit.setDataSource("textfield_company_department_employee_title", "company.department.employee.title");
	toolkit.setDataSource("label_company_department_employee_book_linkedto_list2", "company.department.employee.book");
	toolkit.setLinkSource("list2_company_department_employee_linkedto_list1", "list1_company_department");
	toolkit.setLinkSource("textfield_company_department_employee", "list2_company_department_employee_linkedto_list1");
	toolkit.setLinkSource("textfield_company_department_employee_title", "list2_company_department_employee_linkedto_list1");
	toolkit.setLinkSource("label_company_department_employee_book_linkedto_list2", "list2_company_department_employee_linkedto_list1");
}
/**
 * This method is called when leaving a wizard page, or when
 * either the default, or apply button is pressed on a preferences
 * page.
 */
public void page2onsubmit() {
	
	IToolkitUI toolkit = this.renderer.getToolkit();
	
	toolkit.print("Hi!  This is page2onsubmit!");

	// Get the widget given the id
	//----------------------------
	Object objWidget = this.renderer.getWidget("page2");

	// IDefault is applicable to preference pages
	// but not wizard pages
	//-------------------------------------------
	if (objWidget instanceof IDefault) {
		
		boolean bDefault = ((IDefault) objWidget).isDefault();
		
		if (bDefault == true) {
			toolkit.print("  Default button was pressed");
		}
		
		else {
			toolkit.print("  Apply button was pressed");
		}
	}
}
/**
 * This method is called when a radio button is pressed
 */
public void radio1onclick() {
	this.renderer.getToolkit().print("Hi!  This is radio1onclick!");
}
/**
 * This method is called when a radio button is pressed
 */
public void radio2onclick() {
	this.renderer.getToolkit().print("Hi!  This is radio2onclick!");
}
/**
 * This method is called when a radio button is pressed
 */
public void radio3onclick() {
	this.renderer.getToolkit().print("Hi!  This is radio3onclick!");
}
/**
 * This method is called when a radio button is pressed
 */
public void radio4onclick() {
	this.renderer.getToolkit().print("Hi!  This is radio4onclick!");
}
/**
 * This method is called when a radio button is pressed
 */
public void radio5onclick() {
	this.renderer.getToolkit().print("Hi!  This is radio5onclick!");
}
/**
 * This method is called whenever an action is invoked.
 * A renderer is created and given a user interface presentation model,
 * a presentation rendering type, a data model, and is asked to render the user interface.
 */
private void run() {
	// Create a user interface renderer
	//---------------------------------
	this.renderer = new Renderer();

	// Expose me to the renderer
	//--------------------------
	this.renderer.addObject("excalibur", this);

	// Give the renderer the user interface definition
	// Presentation model is in a file system file
	// Run as either Wizard or Preferences
	//--------------------------------------------
	if (false) {
		this.renderer.setPresentationFilename(this.installLocation + "excaliburScriptRenderer.xhtml", Renderer.WIZARD);
	}

	else {
		this.renderer.setPresentationFilename(this.installLocation + "excaliburScriptRenderer.xhtml", Renderer.PREFERENCES);
	}

	// Optionally, give the renderer a data definition
	//------------------------------------------------
	try {
		IToolkitUI toolkit = this.renderer.getToolkit();
		IDataModel dataModel = null;

		// Data model is in a file system file
		//------------------------------------
		dataModel = toolkit.loadDataModelFromFilename(this.installLocation + "excaliburCompany.xml");

		toolkit.setUIDataModel(dataModel);
	}

	catch (Exception ex) {
		this.renderer.getToolkit().print(ex.toString());
	}

	// Render the user interface
	//--------------------------
	try {
		this.renderer.render(true);
	}

	catch (Exception ex) {
		this.renderer.getToolkit().print(ex.toString());
	}
}
/**
 * This IActionDelegate method is called when a toolbar/menu item is selected.
 * The function selectionChanged is called prior to this call.
 *
 * @param action org.eclipse.jface.IAction
 * @param window org.eclipse.jface.parts.Window
 */
public void run(IAction action) {
	run();
}
/**
 * Selection in the desktop has changed. Plugin provider
 * can use it to change the availability of the action
 * or to modify other presentation properties.
 *
 * <p>Action delegate cannot be notified about
 * selection changes before it is loaded. For that reason,
 * control of action's enable state should also be performed
 * through simple XML rules defined for the extension
 * point. These rules allow enable state control before
 * the delegate has been loaded.</p>
 *
 * @param action action proxy that handles presentation
 * portion of the plugin action
 * @param selection current selection in the desktop
 */
public void selectionChanged(IAction action, ISelection selection) {
	
	if (selection instanceof IStructuredSelection) {
		this.elementSelection = (IStructuredSelection) selection;
	}
}
/**
 * This IExecutableExtension method is called when the extension
 * is created.
 *
 * @param configElement com.ibm.itp.core.api.plugins.IConfigurationElement
 * @param name java.lang.String
 * @param data java.lang.Object
 */
public void setInitializationData(IConfigurationElement configElement, String name, Object data) {
	
	// Save the install location so we can find our files in run()
	//------------------------------------------------------------
	IExtension extension = configElement.getDeclaringExtension();
	IPluginDescriptor pluginDescriptor = extension.getDeclaringPluginDescriptor();
	
	URL url = pluginDescriptor.getInstallURL();
	this.installLocation = url.toExternalForm();
}
}
