package org.eclipse.scripting.examples;

/*
 * (c) Copyright IBM Corp. 2000, 2001.
 * All Rights Reserved.
 */

/**
 * This class is an example of a Scripting program that is
 * an action extension.  This example associates
 * data model elements with user interface elements without having a data
 * model.  The association of a data model element to a user interface element
 * happens in function page2onreset.  The retrieval and display of the current
 * values of the user interface element when the page is closing happens in
 * function page2onsubmit.
 */
import org.eclipse.jface.*;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.core.resources.*;
import org.eclipse.core.runtime.*;
import org.eclipse.ui.IActionDelegate;
import org.eclipse.swt.widgets.*;

import org.eclipse.scripting.*;

public class ExcaliburStringScriptEventHandler extends ScriptAdapterEventHandler 
{
	// These are created in page2onreset
	// and checked on page2onsubmit
	//----------------------------------
	StringDataSingle   stringData1 = null;
	StringDataSingle   stringData2 = null;
	StringDataSingle   stringData3 = null;
	StringDataMultiple stringData4 = null;
	StringDataMultiple stringData5 = null;
	StringDataSingle   stringData6 = null;
	StringDataSingle   stringData7 = null;
	StringDataSingle   stringData8 = null;

	// These are created in page1onreset
	// and checked on page1onsubmit
	//----------------------------------
	StringDataSingle   stringData10 = null;
	StringDataSingle   stringData11 = null;
	StringDataSingle   stringData12 = null;
/**
 * This constructor does nothing other than construct the class
 */
public ExcaliburStringScriptEventHandler() {
	super();
}
/**
 * This method is called when button1 is clicked.
 */
public void button1onclick() {

	// Obtain the toolkit
	IToolkitUI toolkit = getToolkit();

	// Print a greeting
	toolkit.print("Hi!  This is button1onclick!");

	// Obtain a container specification from the user
	try {
		IContainer container = toolkit.promptForWorkspaceContainer(null, "Excalibur");
		
		Text textField = (Text) toolkit.getWidget("textWorkbenchContainer");
		
		if (container != null)
			textField.setText(container.getFullPath().toString());
		else
			textField.setText("");
	} catch (Exception ex) {
		toolkit.print("An exception has occurred in button1click");
		toolkit.print(ex);
	}

	// Obtain the widget that generated the event
	Object objEvent = toolkit.getEventWidget();
	if( objEvent instanceof Button )
	{
		toolkit.print( "This is a button named " + ((Button)objEvent).getText() );
	}
}
/**
 * This method is called when button2 is clicked.
 */
public void button2onclick() {
	IToolkitUI toolkit = getToolkit();
	toolkit.print("Hi!  This is button2onclick!");
	try {
		IFile[] files = toolkit.promptForWorkspaceFiles(null, "File Selection");
		if (files != null) {
			List list = (List) toolkit.getWidget("listWorkbenchFiles");
			list.removeAll();
			for (int i = 0; i < files.length; i++) {
				list.add(files[i].getFullPath().toString());
			}
		}
	} catch (Exception ex) {
		toolkit.print("An exception has occurred in button2click");
		toolkit.print(ex);
	}
}
/**
 * This method is called when button3 is clicked.
 */
public void button3onclick() {
	IToolkitUI toolkit = getToolkit();
	toolkit.print("Hi!  This is button3onclick!");
	try {
		IPath path = toolkit.promptForSystemFolder();
		if (path != null) {
			Text textField = (Text) toolkit.getWidget("textSystemFolder");
			textField.setText(path.toOSString());
		}
	} catch (Exception ex) {
		toolkit.print("An exception has occurred in button3click");
		toolkit.print(ex);
	}
}
/**
 * This method is called when button4 is clicked.
 */
public void button4onclick() {
	IToolkitUI toolkit = getToolkit();
	toolkit.print("Hi!  This is button4onclick!");
	try {
		IPath path = toolkit.promptForSystemFile(false);
		if (path != null) {
			Text textField = (Text) toolkit.getWidget("textSystemFile");
			textField.setText(path.toOSString());
		}
	} catch (Exception ex) {
		toolkit.print("An exception has occurred in button4click");
		toolkit.print(ex);
	}
}
/**
 * This method is called when button5 is clicked.
 */
public void button5onclick() {
	IToolkitUI toolkit = getToolkit();
	toolkit.print("Hi!  This is button5onclick!");
	try {
		String strMessageType = null;
		String strMessage = null;
		Button radio = (Button) toolkit.getWidget("radioInformation");
		if (radio.getSelection() == true) {
			strMessageType = "information";
			strMessage = "Information Message";
		}
		radio = (Button) toolkit.getWidget("radioWarning");
		if (radio.getSelection() == true) {
			strMessageType = "warning";
			strMessage = "Warning Message";
		}
		radio = (Button) toolkit.getWidget("radioError");
		if (radio.getSelection() == true) {
			strMessageType = "error";
			strMessage = "Error Message";
		}
		toolkit.promptForOk("Prompt for OK Title", strMessage, strMessageType);
	} catch (Exception ex) {
		toolkit.print("An exception has occurred in button5click");
		toolkit.print(ex);
	}
}
/**
 * This method is called when button6 is clicked.
 */
public void button6onclick() {
	IToolkit toolkit = getToolkit();
	toolkit.print("Hi!  This is button6onclick!");
	try {
		boolean bOk = toolkit.promptForOkCancel("Prompt for OK/Cancel Title", "Prompt for OK/Cancel Message");
		if (bOk == true) {
			toolkit.print("  OK button was pressed");
		} else {
			toolkit.print("  Cancel button was pressed");
		}
	} catch (Exception ex) {
		toolkit.print("An exception has occurred in button6click");
		toolkit.print(ex);
	}
}
/**
 * This method is called when the wizard or prefereneces dialog is loaded.
 */
public void dialog1onload() {
	IToolkitUI toolkit = getToolkit();

 	toolkit.print("Hi!  This is dialog1onload!");
	toolkit.print( "  Plugin is: " + toolkit.getPlugin() );

	IResource[] resourcesSelected = toolkit.getResourcesSelected();

	if( resourcesSelected.length > 0 ) {
		toolkit.print( "  Resources selected are:" );
		for( int i=0; i<resourcesSelected.length; ++i )	{
			toolkit.print( "    " + resourcesSelected[i].getName() );
		}
	}

	else {
		toolkit.print( "  There are no resources selected" );
	}
}
/**
 * This method is called when either the wizard or preferences dialog is closed.
 */
public void dialog1onunload() {
	IToolkitUI toolkit = getToolkit();
	toolkit.print("Hi!  This is dialog1onunload!");

	// Get the widget given the id
	//----------------------------
	Object objWidget = toolkit.getWidget("dialog1");
	boolean bCancel = ((ICancel) objWidget).isCancel();
	if (bCancel == true) {
		toolkit.print("  Cancel button was pressed");
	} else {
		toolkit.print("  Finish button was pressed");
	}
}
/**
 * This method is called when a selection on a listbox has changed.
 */
public void list1onchange() {
	getToolkit().print("Hi!  This is list1onchange!");
}
/**
 * This method is called when the first page is opened.
 */
public void page1onreset() {
	IToolkitUI toolkit = getToolkit();
	toolkit.print("Hi!  This is page1onreset!");

	stringData10 = new StringDataSingle( "true",   null );
	toolkit.setStringDataSource( "radioWorkbench",  stringData10  );

	stringData11 = new StringDataSingle( "false",   null );
	toolkit.setStringDataSource( "radioFileSystem",  stringData11  );

	stringData12 = new StringDataSingle( "true",   null );
	toolkit.setStringDataSource( "checkbox1",  stringData12  );
}
/**
 * This method is called when leaving a wizard page, or when
 * either the default, or apply button is pressed on a preferences
 * page.
 */
public void page1onsubmit() {
	IToolkitUI toolkit = getToolkit();
	toolkit.print("Hi!  This is page1onsubmit!");

	// Get the widget given the id
	//----------------------------
	Object objWidget = toolkit.getWidget("page1");

	// IDefault is applicable to preference pages
	// but not wizard pages
	//-------------------------------------------
	if (objWidget instanceof IDefault) {
		boolean bDefault = ((IDefault) objWidget).isDefault();
		if (bDefault == true) {
			toolkit.print("  Default button was pressed");
		} else {
			toolkit.print("  Apply button was pressed");
		}
	}

	// Retrieve and print the current values of the user interface elements
	//---------------------------------------------------------------------
	toolkit.print( "  stringData10: " + stringData10.getString() );
	toolkit.print( "  stringData11: " + stringData11.getString() );
	toolkit.print( "  stringData12: " + stringData12.getString() );
}
/**
 * This method is called when the second page is opened.  User interface elements
 * are associated with a datamodel's data source.  Some user interface elements are
 * linked to other user interface element sources.
 */
public void page2onreset() {
	IToolkitUI toolkit = getToolkit();
	toolkit.print("Hi!  This is page2onreset!");

	// Setup data values and associate with user interface elements
	// The string values are typically obtained from a user data model
	// To associate a data model element with the string data, use
	// the StringData constructor that has two parameters
	//----------------------------------------------------------------
	stringData1 = new StringDataSingle( "Street",   null );
	toolkit.setStringDataSource( "company_address_street",  stringData1  );
	
	stringData2 = new StringDataSingle( "City",   null );
	toolkit.setStringDataSource( "company_address_city",    stringData2 );
	
	stringData3 = new StringDataSingle( "Country", null );
	toolkit.setStringDataSource( "company_address_country", stringData3 );

	String[] strings = new String[3];
	Object[] objects = new Object[3];

	strings[0] = "Department One";
	strings[1] = "Department Two";
	strings[2] = "Department Three";

	objects[0] = new Object();
	objects[1] = new Object();
	objects[2] = new Object();
	
	stringData4 = new StringDataMultiple( strings, objects );
	toolkit.setStringDataSource( "list1_company_department", stringData4 );

	strings = new String[3];
	objects = new Object[3];

	strings[0] = "Employee One";
	strings[1] = "Employee Two";
	strings[2] = "Employee Three";

	objects[0] = new Object();
	objects[1] = new Object();
	objects[2] = new Object();
	
	stringData5 = new StringDataMultiple( strings, objects );
	toolkit.setStringDataSource( "list2_company_department_employee_linkedto_list1", stringData5 );
	
	stringData6 = new StringDataSingle( "Employee Name", null );
	toolkit.setStringDataSource( "textfield_company_department_employee", stringData6 );
	
	stringData7 = new StringDataSingle( "Employee Title", null );
	toolkit.setStringDataSource( "textfield_company_department_employee_title", stringData7 );

	stringData8 = new StringDataSingle( "Book Title", null );
	toolkit.setStringDataSource( "label_company_department_employee_book_linkedto_list2", stringData8 );
}
/**
 * This method is called when leaving a wizard page, or when
 * either the default, or apply button is pressed on a preferences
 * page.
 */
public void page2onsubmit() {
	IToolkitUI toolkit = getToolkit();
	toolkit.print("Hi!  This is page2onsubmit!");

	// Get the widget given the id
	//----------------------------
	Object objWidget = toolkit.getWidget("page2");

	// IDefault is applicable to preference pages
	// but not wizard pages
	//-------------------------------------------
	if (objWidget instanceof IDefault) {
		boolean bDefault = ((IDefault) objWidget).isDefault();
		if (bDefault == true) {
			toolkit.print("  Default button was pressed");
		} else {
			toolkit.print("  Apply button was pressed");
		}
	}

	// Retrieve and print the current values of the user interface elements
	//---------------------------------------------------------------------
	toolkit.print( "  stringData1: " + stringData1.getString() );
	toolkit.print( "  stringData2: " + stringData2.getString() );
	toolkit.print( "  stringData3: " + stringData3.getString() );

	// List departments
	//-----------------
	toolkit.print( "  stringData4" );
	printWidgetSelection( toolkit.getWidget( "list1_company_department" ), stringData4, toolkit );
	
	// List employees
	//---------------
	toolkit.print( "  stringData5" );
	printWidgetSelection( toolkit.getWidget( "list2_company_department_employee_linkedto_list1" ), stringData5, toolkit );
	
	toolkit.print( "  stringData6: " + stringData6.getString() );
	toolkit.print( "  stringData7: " + stringData7.getString() );
	toolkit.print( "  stringData8: " + stringData8.getString() );
}
/**
 * Prints the selected items from a List or Combo widget.  The selected
 * indices are used to index the String array obtained from StrinDataMultiple.
 * The indices can also be used to index the Object array from StringDataMultiple.
 */
private void printWidgetSelection(Object widget, StringDataMultiple stringData, IToolkitUI toolkit) {

	String[] strings = stringData.getStrings();
	
	// List
	//-----
	if (widget instanceof List) {

		// Obtain the selected indices
		//----------------------------
		int[] iaSelected = ((List) widget).getSelectionIndices();

		// Print the indices and the strings
		//----------------------------------
		for (int i = 0; i < iaSelected.length; ++i) {
			toolkit.print("    " + Integer.toString(iaSelected[i]) + ": " + strings[i]);
		}
	}

	// Combo
	//------
	else
		if (widget instanceof Combo) {

			// Obtain the selected index
			//--------------------------
			int iSelected = ((Combo) widget).getSelectionIndex();

			// The text was selected from the list
			//------------------------------------
			if (iSelected >= 0) {
				toolkit.print("    Text was selected from the list at index: " + Integer.toString(iSelected));
				toolkit.print("    " + strings[iSelected]);
			}

			// The text was not selected from the list
			//----------------------------------------
			else {
				toolkit.print("    Text was not selected from the list");
				toolkit.print("    " + ((Combo) widget).getText());
			}
		}
}
/**
 * This method is called when a radio button is pressed
 */
public void radio1onclick() {
	getToolkit().print("Hi!  This is radio1onclick!");
}
/**
 * This method is called when a radio button is pressed
 */
public void radio2onclick() {
	getToolkit().print("Hi!  This is radio2onclick!");
}
/**
 * This method is called when a radio button is pressed
 */
public void radio3onclick() {
	getToolkit().print("Hi!  This is radio3onclick!");
}
/**
 * This method is called when a radio button is pressed
 */
public void radio4onclick() {
	getToolkit().print("Hi!  This is radio4onclick!");
}
/**
 * This method is called when a radio button is pressed
 */
public void radio5onclick() {
	getToolkit().print("Hi!  This is radio5onclick!");
}
}
