package org.eclipse.scripting.examples;

/*
 * (c) Copyright IBM Corp. 2000, 2001.
 * All Rights Reserved.
 */

/**
 * This class is an example of an event handler that handles user interface events
 * for a script that is rendered using a script adapter.
 */
import org.eclipse.jface.*;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.core.resources.*;
import org.eclipse.core.runtime.*;
import org.eclipse.ui.IActionDelegate;
import org.eclipse.swt.widgets.*;

import org.eclipse.scripting.*;

public class ExcaliburWorkbenchNewWizardAdapterScriptEventHandler extends ScriptAdapterEventHandler {
/**
 * This constructor does nothing other than construct the class
 */
public ExcaliburWorkbenchNewWizardAdapterScriptEventHandler() {
	super();
}
/**
 * This method is called when button1 is clicked.
 */
public void button1onclick() {

	// Obtain the toolkit
	IToolkitUI toolkit = getToolkit();

	// Print a greeting
	toolkit.print("Hi!  This is button1onclick!");

	// Obtain a container specification from the user
	try {
		IContainer container = toolkit.promptForWorkspaceContainer(null, "Excalibur");
		if (container != null) {
			Text textField = (Text) toolkit.getWidget("textWorkspaceContainer");
			textField.setText(container.getLocation().toString());
		}
	} catch (Exception ex) {
		toolkit.print("An exception has occurred in button1click");
		toolkit.print(ex);
	}

	// Obtain the widget that generated the event
	Object objWidget = toolkit.getEventWidget();

	if( objWidget instanceof Button )
	{
		toolkit.print( "Button has label " + ((Button)objWidget).getText() );
	}
}
/**
 * This method is called when button2 is clicked.
 */
public void button2onclick() {

	IToolkitUI toolkit = getToolkit();
	toolkit.print("Hi!  This is button2onclick!");

	Text textField = (Text) toolkit.getWidget("textWorkspaceContainer");
	String strContainer = textField.getText();

	if (strContainer != null && strContainer.length() > 0) {

		Path pathContainer = new Path(strContainer);

		IWorkspace workspace = ResourcesPlugin.getWorkspace();

		IContainer container = workspace.getRoot().getContainerForLocation(pathContainer);

		try {
			IFile[] files = toolkit.promptForWorkspaceFiles(container, "File Selection");
			if (files != null) {
				List list = (List) toolkit.getWidget("listWorkspaceFiles");
				list.removeAll();
				for (int i = 0; i < files.length; i++) {
					list.add(files[i].getFullPath().toString());
				}
			}
		}
		catch (Exception ex) {
			toolkit.print("An exception has occurred in button2click");
			toolkit.print(ex);
		}
	}
}
/**
 * This method is called when button3 is clicked.
 */
public void button3onclick() {

	IToolkitUI toolkit = getToolkit();

	toolkit.print("Hi!  This is button3onclick!");

	try {
		IPath path = toolkit.promptForSystemFolder();

		if (path != null) {

			Text textField = (Text) toolkit.getWidget("textSystemFolder");
			textField.setText(path.toOSString());
		}
	}

	catch (Exception ex) {
		toolkit.print("An exception has occurred in button3click");
		toolkit.print(ex);
	}
}
/**
 * This method is called when button4 is clicked.
 */
public void button4onclick() {
	
	IToolkitUI toolkit = getToolkit();
	
	toolkit.print("Hi!  This is button4onclick!");
	
	try {
		IPath path = toolkit.promptForSystemFile(false);
		
		if (path != null) {
			Text textField = (Text) toolkit.getWidget("textSystemFile");
			textField.setText(path.toOSString());
		}
	}
	
	catch (Exception ex) {
		toolkit.print("An exception has occurred in button4click");
		toolkit.print(ex);
	}
}
/**
 * This method is called when button5 is clicked.
 */
public void button5onclick() {
	
	IToolkitUI toolkit = getToolkit();
	
	toolkit.print("Hi!  This is button5onclick!");
	
	try {
		String strMessageType = null;
		String strMessage = null;
		
		Button radio = (Button) toolkit.getWidget("radioInformation");
		
		if (radio.getSelection() == true) {
			strMessageType = "information";
			strMessage = "Information Message";
		}
		
		radio = (Button) toolkit.getWidget("radioWarning");
		
		if (radio.getSelection() == true) {
			strMessageType = "warning";
			strMessage = "Warning Message";
		}
		
		radio = (Button) toolkit.getWidget("radioError");
		
		if (radio.getSelection() == true) {
			strMessageType = "error";
			strMessage = "Error Message";
		}
		
		toolkit.promptForOk("Prompt for OK Title", strMessage, strMessageType);
	}
	
	catch (Exception ex) {
		toolkit.print("An exception has occurred in button5click");
		toolkit.print(ex);
	}
}
/**
 * This method is called when button6 is clicked.
 */
public void button6onclick() {

	IToolkit toolkit = getToolkit();

	toolkit.print("Hi!  This is button6onclick!");

	try {
		boolean bOk = toolkit.promptForOkCancel("Prompt for OK/Cancel Title", "Prompt for OK/Cancel Message");

		if (bOk == true) {
			toolkit.print("  OK button was pressed");
		}
		
		else {
			toolkit.print("  Cancel button was pressed");
		}
	}
	
	catch (Exception ex) {
		toolkit.print("An exception has occurred in button6click");
		toolkit.print(ex);
	}
}
/**
 * This method is called when the wizard or prefereneces dialog is loaded.
 */
public void dialog1onload() {
	
	IToolkitUI toolkit = getToolkit();

	toolkit.print("Hi!  This is dialog1onload!");
	
	toolkit.print("Plugin is: " + toolkit.getPlugin());

	IResource[] resourcesSelected = toolkit.getResourcesSelected();

	if (resourcesSelected.length > 0) {
		
		toolkit.print("Resources selected are:");
		
		for (int i = 0; i < resourcesSelected.length; ++i) {
			toolkit.print("  " + resourcesSelected[i].getName());
		}
	}

	else {
		toolkit.print("There are no resources selected");
	}
}
/**
 * This method is called when either the wizard or preferences dialog is closed.
 */
public void dialog1onunload() {
	
	IToolkitUI toolkit = getToolkit();
	
	toolkit.print("Hi!  This is dialog1onunload!");

	// Get the widget given the id
	//----------------------------
	Object objWidget = toolkit.getWidget("dialog1");
	
	boolean bCancel = ((ICancel) objWidget).isCancel();
	
	if (bCancel == true) {
		toolkit.print("  Cancel button was pressed");
	}
	
	else {
		toolkit.print("  Finish button was pressed.");
/*
		// Save the data
		//--------------
		IDataModel dataModel = getToolkit().getUIDataModel();
		
		if (dataModel != null) {
			
			try {
				dataModel.save();
			}
			
			catch (Exception ex) {
				toolkit.print(ex.toString());
			}
		}
*/
	}
}
/**
 * This method is called when a selection on a listbox has changed.
 */
public void list1onchange() {
	getToolkit().print("Hi!  This is list1onchange!");
}
/**
 * This method is called when the first page is opened.
 */
public void page1onreset() {
	getToolkit().print("Hi!  This is page1onreset!");
}
/**
 * This method is called when leaving a wizard page, or when
 * either the default, or apply button is pressed on a preferences
 * page.
 */
public void page1onsubmit() {
	
	IToolkitUI toolkit = getToolkit();
	
	toolkit.print("Hi!  This is page1onsubmit!");

	// Get the widget given the id
	//----------------------------
	Object objWidget = toolkit.getWidget("page1");

	// IDefault is applicable to preference pages
	// but not wizard pages
	//-------------------------------------------
	if (objWidget instanceof IDefault) {
		
		boolean bDefault = ((IDefault) objWidget).isDefault();
		
		if (bDefault == true) {
			toolkit.print("  Default button was pressed");
		}
		
		else {
			toolkit.print("  Apply button was pressed");
		}
	}
}
/**
 * This method is called when the second page is opened.  User interface elements
 * are associated with a datamodel's data source.  Some user interface elements are
 * linked to other user interface element sources.
 */
public void page2onreset() {
	
	IToolkitUI toolkit = getToolkit();
	
	toolkit.print("Hi!  This is page2onreset!");
	
	toolkit.setDataSource("company_address_street", "company.address.street");
	toolkit.setDataSource("company_address_city", "company.address.city");
	toolkit.setDataSource("company_address_country", "company.address.country");
	toolkit.setDataSource("list1_company_department", "company.department.number");
	toolkit.setDataSource("list2_company_department_employee_linkedto_list1", "company.department.employee.name");
	toolkit.setDataSource("textfield_company_department_employee", "company.department.employee.name");
	toolkit.setDataSource("textfield_company_department_employee_title", "company.department.employee.title");
	toolkit.setDataSource("label_company_department_employee_book_linkedto_list2", "company.department.employee.book");
	toolkit.setLinkSource("list2_company_department_employee_linkedto_list1", "list1_company_department");
	toolkit.setLinkSource("textfield_company_department_employee", "list2_company_department_employee_linkedto_list1");
	toolkit.setLinkSource("textfield_company_department_employee_title", "list2_company_department_employee_linkedto_list1");
	toolkit.setLinkSource("label_company_department_employee_book_linkedto_list2", "list2_company_department_employee_linkedto_list1");
}
/**
 * This method is called when leaving a wizard page, or when
 * either the default, or apply button is pressed on a preferences
 * page.
 */
public void page2onsubmit() {
	
	IToolkitUI toolkit = getToolkit();
	
	toolkit.print("Hi!  This is page2onsubmit!");

	// Get the widget given the id
	//----------------------------
	Object objWidget = toolkit.getWidget("page2");

	// IDefault is applicable to preference pages
	// but not wizard pages
	//-------------------------------------------
	if (objWidget instanceof IDefault) {
		
		boolean bDefault = ((IDefault) objWidget).isDefault();
		
		if (bDefault == true) {
			toolkit.print("  Default button was pressed");
		}
		
		else {
			toolkit.print("  Apply button was pressed");
		}
	}
}
/**
 * This method is called when a radio button is pressed
 */
public void radio1onclick() {
	getToolkit().print("Hi!  This is radio1onclick!");
}
/**
 * This method is called when a radio button is pressed
 */
public void radio2onclick() {
	getToolkit().print("Hi!  This is radio2onclick!");
}
/**
 * This method is called when a radio button is pressed
 */
public void radio3onclick() {
	getToolkit().print("Hi!  This is radio3onclick!");
}
/**
 * This method is called when a radio button is pressed
 */
public void radio4onclick() {
	getToolkit().print("Hi!  This is radio4onclick!");
}
/**
 * This method is called when a radio button is pressed
 */
public void radio5onclick() {
	getToolkit().print("Hi!  This is radio5onclick!");
}
}
